# Table of Contents

- [modeling-best-practices](<./modeling-best-practices.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling Best Practices](<./Modeling-Best-Practices.md>)
  - [Modeling Major IT Systems](<./Modeling-Best-Practices/Modeling-Major-IT-Systems.md>)
  - [Import Templates](<./Modeling-Best-Practices/Import-Templates.md>)
